===========
bruges is a
===========

.. image:: http://kwinkunks.pythonanywhere.com/bruges

In other words, it's just a load of functions that implement important equations in (mostly seismic) geophysics, from Aki-Richards to Zoeppritz.


Status
+++++++

.. image:: https://img.shields.io/travis/agile-geoscience/bruges.svg
    :target: https://travis-ci.org/agile-geoscience/bruges
    :alt: Travis build status
    
.. image:: https://img.shields.io/pypi/status/bruges.svg
    :target: https://pypi.python.org/pypi/bruges/
    :alt: Development status

.. image:: https://img.shields.io/pypi/v/bruges.svg
    :target: https://pypi.python.org/pypi/bruges/
    :alt: Latest version
    
.. image:: https://img.shields.io/pypi/pyversions/bruges.svg
    :target: https://pypi.python.org/pypi/bruges/
    :alt: Python version

.. image:: https://coveralls.io/repos/agile-geoscience/bruges/badge.svg?branch=master&service=github
  :target: https://coveralls.io/github/agile-geoscience/bruges?branch=master

.. image:: https://img.shields.io/codacy/f445542bc50e48c18a0d0e15a2768eb7.svg 
    :target: https://www.codacy.com/app/matt/bruges/dashboard
    :alt: Codacy code review

.. image:: https://img.shields.io/pypi/l/bruges.svg
    :target: http://www.apache.org/licenses/LICENSE-2.0
    :alt: License

.. line-block::
   The bruges module contains several common geophysics functions 
   used for modelling and post-processing seismic reflection data.


Installation
++++++++++++
Install with

.. code-block:: shell

    pip install bruges

**bruges** requires NumPy and SciPy.


Contributors
++++++++++++
* Evan Bianco
* Ben Bougher
* Matt Hall
* Alessandro Amato del Monte
* Wes Hamlyn
* Sean Ross-Ross


Links
+++++
* `Documentation <https://bruges.readthedocs.org/en/latest/>`_
* `Project page <http://agile-geoscience.github.com/bruges/>`_
* `Issue Tracker <https://github.com/agile-geoscience/bruges/issues/>`_
* `PyPi <http://pypi.python.org/pypi/bruges/>`_
* `Agile Geoscience <http://www.agilegeoscience.com>`_
